@@ -43,6 +43,12 @@ class SourceTap(ABC):
         self.topic = settings.topic
         self.logger = logger
 
+    def __str__(self) -> str:
+        return self.__repr__()
+
+    def __repr__(self) -> str:
+        return f"Source(topic=({self.topic}), settings=({self.settings}))"
+
     @abstractmethod
     def read(self) -> Iterator[MessageBase]:
         """receive message."""
@@ -101,6 +107,12 @@ class DestinationTap(ABC):
         self.topic = settings.topic
         self.logger = logger
 
+    def __str__(self) -> str:
+        return self.__repr__()
+
+    def __repr__(self) -> str:
+        return f"Destination(topic=({self.topic}), settings=({self.settings}))"
+
     @abstractmethod
     def write(self, message: MessageBase) -> int:
         """send message."""
@@ -152,10 +164,11 @@ class MemorySource(SourceTap):
         self, settings: MemorySourceSettings, logger: Logger = pipelineLogger
     ) -> None:
         super().__init__(settings, logger)
-        self.data = settings.data
-        self.storage = [
-            Message(content=content).serialize() for content in settings.data
-        ]
+
+        self.reset()
+
+    def reset(self):
+        self.load_data(self.settings.data)
 
     def load_data(self, data):
         self.data = data
@@ -195,6 +208,10 @@ class MemoryDestination(DestinationTap):
         self.results: List[MessageBase] = []
         self.storage: List[bytes] = []
 
+    def reset(self):
+        self.results = []
+        self.storage = []
+
     def write(self, message: MessageBase) -> int:
         self.results.append(message)
         self.storage.append(serialize_message(message))
